/* Copyright (C) 2000-2002 Lavtech.com corp. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
*/

#ifndef _UDM_CHINESE_H
#define _UDM_CHINESE_H

extern int *UdmSegmentByFreq(UDM_CHINALIST *List, int *line);
extern __C_LINK void __UDMCALL UdmChineseListFree(UDM_CHINALIST *List);
extern int UdmChineseListLoad(UDM_AGENT *Agent, UDM_CHINALIST *List, const char *charset, const char * chineselist_filename);

#endif
